@@ -31,7 +31,7 @@ has pubsub => sub {
 };
 
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 sub db {
   my $self = shift;
@@ -73,6 +73,14 @@ sub from_string {
 
 sub new { @_ > 1 ? shift->SUPER::new->from_string(@_) : shift->SUPER::new }
 
+sub strict_mode {
+  my $self = ref $_[0] ? shift : shift->new(@_);
+  $self->{strict_mode} = $_[0] ? 1 : @_ ? 0 : 1;
+  warn "[Mojo::mysql] strict_mode($self->{strict_mode})\n" if $ENV{DBI_TRACE};
+  delete @$self{qw(pid queue)};
+  return $self;
+}
+
 sub _dequeue {
   my $self = shift;
   my $dbh;
@@ -89,6 +97,7 @@ sub _dequeue {
   # Maintain Commits with Mojo::mysql::Transaction
   $dbh->{AutoCommit} = 1;
 
+  $self->_set_strict_mode($dbh) if $self->{strict_mode};
   $self->migrations->migrate if $self->auto_migrate and !$self->{migrated}++;
   $self->emit(connection => $dbh);
   [$dbh];
@@ -101,6 +110,11 @@ sub _enqueue {
   shift @{$self->{queue}} while @{$self->{queue}} > $self->max_connections;
 }
 
+sub _set_strict_mode {
+  $_[1]->do(q[SET SQL_MODE = CONCAT('ANSI,TRADITIONAL,ONLY_FULL_GROUP_BY,', @@sql_mode)]);
+  $_[1]->do(q[SET SQL_AUTO_IS_NULL = 0]);
+}
+
 1;
 
 =encoding utf8
@@ -114,7 +128,7 @@ Mojo::mysql - Mojolicious and Async MySQL
   use Mojo::mysql;
 
   # Create a table
-  my $mysql = Mojo::mysql->new('mysql://username@/test');
+  my $mysql = Mojo::mysql->strict_mode('mysql://username@/test');
   $mysql->db->query(
     'create table names (id integer auto_increment primary key, name text)');
 
@@ -192,7 +206,7 @@ gracefully by holding on to them only for short amounts of time.
   use Mojo::mysql;
 
   helper mysql =>
-    sub { state $mysql = Mojo::mysql->new('mysql://sri:s3cret@localhost/db') };
+    sub { state $mysql = Mojo::mysql->strict_mode('mysql://sri:s3cret@localhost/db') };
 
   get '/' => sub {
     my $c  = shift;
@@ -399,6 +413,28 @@ Parse configuration from connection string.
 Construct a new L<Mojo::mysql> object and parse connection string with
 L</"from_string"> if necessary.
 
+=head2 strict_mode
+
+  my $mysql = Mojo::mysql->strict_mode('mysql://user@/test');
+  my $mysql = $mysql->strict_mode($boolean);
+
+This method can act as both a constructor and a method. When called as a
+constructor, it will be the same as:
+
+  my $mysql = Mojo::mysql->new('mysql://user@/test')->strict_mode(1);
+
+Enabling strict mode will execute the following statement when a new connection
+is created:
+
+  SET SQL_MODE = CONCAT('ANSI,TRADITIONAL,ONLY_FULL_GROUP_BY,', @@sql_mode)
+  SET SQL_AUTO_IS_NULL = 0
+
+The idea is to set up a connection that makes it harder for MySQL to allow
+"invalid" data to be inserted.
+
+This method will not be removed, but the internal commands is subject to
+change.
+
 =head1 DEBUGGING
 
 You can set the C<DBI_TRACE> environment variable to get some advanced
